@@ -10,7 +10,7 @@ from collections import namedtuple
 from enum import Enum
 from typing import List
 
-version = '0.2.76'
+version = '3.1.18'
 version_info = list(map(int, version.split('.')))
 
 
@@ -58,7 +58,7 @@ class ComponentType():
     AioHttp = "AioHttp"
     Pyramid = "Pyramid"
     CustomEvent = "CustomEvent"
-    Log = "logging"
+    Log = "Log"
 
 
 class Layer(Enum):
@@ -70,7 +70,6 @@ class Layer(Enum):
     Cache = 5
     User = 6
     Log = 7
-    Function = 8
 
 
 class Kind(Enum):
